@@ -2,11 +2,11 @@ from functools import partial
 
 from kappadata.datasets.kd_dataset import KDDataset
 from .mode_wrapper import ModeWrapper
-from functools import partial
+
 
 class TorchWrapper(KDDataset):
-    def __init__(self, dataset, mode, **kwargs):
-        super().__init__(**kwargs)
+    def __init__(self, dataset, mode):
+        super().__init__()
         self.dataset = dataset
         self.mode = mode
 
@@ -26,4 +26,4 @@ class TorchWrapper(KDDataset):
         return batch[item_idx]
 
     def __len__(self):
-        return len(self.dataset)
\ No newline at end of file
+        return len(self.dataset)
